@@ -1,4 +1,7 @@
+import pandas as pd
+
 from tyba_client.models import GenerationModel, PVStorageModel, StandaloneStorageModel
+from generation_models import JobModel
 import json
 import requests
 import time
@@ -101,10 +104,16 @@ class Client(object):
         model_json_dict = pv_storage_model.to_dict()
         return self.post("schedule-pv-storage", json=model_json_dict)
 
+    def schedule(self, model: JobModel):
+        return self.post("schedule-job", json=model.dict())
+
     def get_status(self, run_id: str):
         url = "get-status/" + run_id
         return self.get(url)
 
+    def get_status_v1(self, run_id: str):
+        return self.get(f"get-status/{run_id}", params={"fmt": "v1"})
+
     def wait_on_result(self, run_id: str, wait_time: int = 5):
         while True:
             res = self.get_status(run_id).json()
@@ -114,6 +123,22 @@ class Client(object):
                 raise UnknownRunId(f"No known model run with run_id '{run_id}'")
             time.sleep(wait_time)
 
+    def wait_on_result_v1(self, run_id: str, wait_time: int = 5):
+        while True:
+            res = self.get_status_v1(run_id).json()
+            if res["status"] == "complete":
+                return parse_v1_result(res)
+            elif res["status"] == "unknown":
+                raise UnknownRunId(f"No known model run with run_id '{run_id}'")
+            time.sleep(wait_time)
+
+
+def parse_v1_result(res: dict):
+    return {
+        "hourly": pd.concat({k: pd.DataFrame(v) for k, v in res["result"]["hourly"].items()}, axis=1),
+        "waterfall": res["result"]["waterfall"]
+    }
+
 
 class UnknownRunId(ValueError):
     pass
